@@ -18,7 +18,7 @@
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA *
 *                                                                             *
 *  Contact: Guillaume.Huard@imag.fr                                           *
-*           ENSIMAG - Laboratoire ID                                          *
+*           ENSIMAG - Laboratoire d'Informatique de Grenoble                  *
 *           51 avenue Jean Kuntzmann                                          *
 *           38330 Montbonnot Saint Martin                                     *
 *                                                                             *
@@ -32,9 +32,10 @@ int main()
     char buffer[1024];
     size_t length;
     char sample_string[128] = "Salut  toi";
-    long rank, from;
+    unsigned long rank, from;
     int result;
 
+    printf("Hellooo...\n");
     result = taktuk_get("rank", &rank);
     if (result)
       {
@@ -42,28 +43,28 @@ int main()
                                                      taktuk_error_msg(result));
         return 1;
       }
-    printf("I'm process %ld\n", rank);
+    printf("I'm process %lu\n", rank);
 
     if (rank == 1)
       {
-        result = taktuk_send(2, sample_string, 128);
+        result = taktuk_send(2, TAKTUK_TARGET_ANY, sample_string, 128);
         if (result)
           {
-            printf("Error in %ld : %s\n", rank, taktuk_error_msg(result));
+            printf("Error in %lu : %s\n", rank, taktuk_error_msg(result));
           }
       }
     else if (rank == 2)
       {
         fflush(stdout);
-        result = taktuk_recv(&from, buffer, &length, 0);
+        result = taktuk_recv(&from, buffer, &length, NULL);
         if (result)
           {
-            printf("Error in %ld : %s\n", rank, taktuk_error_msg(result));
+            printf("Error in %lu : %s\n", rank, taktuk_error_msg(result));
           }
         else
           {
-            printf("Received : %s of length %ld from %ld\n", buffer, length,
-                                                                         from);
+            printf("Received : %s of length %lu from %lu\n", buffer,
+                                                  (unsigned long) length, from);
           }
       }
     else
